CellDecoratorClone

Trait CellDecoratorClone 

pub trait CellDecoratorClone {
    // Required method
    fn clone_box(&self) -> Box<dyn CellDecorator>;
}
A helper trait to make CellDecorator objects cloneable as trait objects.

This is implemented automatically for any T that implements CellDecorator + Clone. It provides a clone_box method used to clone boxed decorators.

Required Methods

fn clone_box(&self) -> Box<dyn CellDecorator>

Clone the boxed decorator into a new boxed trait object.

Implementors

Source

impl<T> CellDecoratorClone for T
where T: CellDecorator + Clone + 'static,