pub trait CellDecoratorClone {
// Required method
fn clone_box(&self) -> Box<dyn CellDecorator>;
}Expand description
A helper trait to make CellDecorator objects cloneable as trait objects.
This is implemented automatically for any T that implements CellDecorator + Clone.
It provides a clone_box method used to clone boxed decorators.
Required Methods
Sourcefn clone_box(&self) -> Box<dyn CellDecorator>
fn clone_box(&self) -> Box<dyn CellDecorator>
Clone the boxed decorator into a new boxed trait object.